@@ -15,6 +15,7 @@ from tests.db_test_case import TEST_DB_CONNSTR, PgTestCase
 
 
 class ConcreteTimeSeriesTable(AbstractTimeSeriesTable):
+    """Creates the Concrete Time Series Table Object."""
 
     __tablename__ = "test_data"
 
@@ -42,6 +43,8 @@ class ConcreteTimeSeriesTable(AbstractTimeSeriesTable):
 
 
 class ConcreteAdNetworkJoinTimeSeriesTable(AbstractIDBase):
+    """Creates the Concrete Ad Network Object."""
+
     __tablename__ = "test_ad_network_join_data"
 
     ad_network = Column(String(64))
@@ -49,6 +52,8 @@ class ConcreteAdNetworkJoinTimeSeriesTable(AbstractIDBase):
 
 
 class ConcretePlacementIdJoinTimeSeriesTable(AbstractIDBase):
+    """Creates the Concrete Placement Id Object."""
+
     __tablename__ = "test_placement_id_join_data"
 
     placement_id = Column(String(256))
@@ -121,6 +126,8 @@ aggregated_column_mappings = {
 
 @unittest.skipIf(not os.getenv(TEST_DB_CONNSTR), f"{TEST_DB_CONNSTR} is not set")
 class TestDatasetStore(PgTestCase):
+    """Test dataset store object."""
+
     def _test_load(
         self,
         columns,
@@ -133,6 +140,7 @@ class TestDatasetStore(PgTestCase):
         extra_where_conditions=None,
         extra_having_conditions=None,
         inner_join=None,
+        table_mapping=None,
     ):
         df = self.time_series_extractor.extract(
             build_query_kwargs=dict(
@@ -147,6 +155,7 @@ class TestDatasetStore(PgTestCase):
                 column_mappings=column_mappings,
                 aggregated_column_mappings=aggregated_column_mappings,
                 inner_join=inner_join,
+                table_mapping=table_mapping,
             )
         )
         # Fix for backwards compatible with original tests.
@@ -230,6 +239,33 @@ class TestDatasetStore(PgTestCase):
             ],
         )
 
+    def test_join_tables_with_alias(self):
+        columns = [
+            TIMESTAMP_COL,
+            "opportunities",
+            "b.ad_network",
+            "ad_network_group",
+        ]
+        values = [
+            ['2019-09-01', 1000, 'source1', 'source_group_B'],
+            ['2019-09-01', 1000, 'source2', 'source_group_A'],
+            ['2019-09-01', 1000, 'source2', 'source_group_A'],
+            ['2019-09-02', 300, 'source2', 'source_group_A'],
+        ]
+        self._test_load(
+            columns=columns,
+            dimensions=None,
+            dimensions_values=None,
+            start_date=None,
+            end_date=None,
+            order_by=None,
+            expected_values=values,
+            table_mapping='a',
+            inner_join=[
+                ("test_ad_network_join_data", 'b', "b.ad_network = a.ad_network",)
+            ],
+        )
+
     def test_multiple_join_load_basic_columns_order_by(self):
         columns = [
             TIMESTAMP_COL,
@@ -675,7 +711,7 @@ class TestDatasetStore(PgTestCase):
         ]
         self.assertEqual(ret, expected)
 
-    def test_builded_query(self):
+    def test_builded_query_prequery(self):
         columns = [
             "timestamp",
             "game",
@@ -701,6 +737,32 @@ class TestDatasetStore(PgTestCase):
         return_query = "SET extra_float_digits = 3; SELECT timestamp, game, country, ad_network, ad_type, placement_id FROM test_data WHERE timestamp >= '2019-09-01' AND timestamp <= '2019-09-02' ORDER BY ad_type"
         self.assertEqual(returned_query, return_query)
 
+    def test_builded_query_extra_cond(self):
+        columns = [
+            "timestamp",
+            "game",
+            "country",
+            "ad_network",
+            "ad_type",
+            "placement_id",
+        ]
+        order_by = ["ad_type"]
+        start_date = "2019-09-01"
+        end_date = "2019-09-02"
+        extra_where_conditions = ["game LIKE '%mario%'"]
+
+        query = self.time_series_extractor.build_query(
+            columns=columns,
+            start_date=start_date,
+            end_date=end_date,
+            order_by=order_by,
+            extra_where_conditions=extra_where_conditions,
+        )
+        # remove empty spaces and new lines
+        returned_query = " ".join(query[0].split())
+        return_query = "SELECT timestamp, game, country, ad_network, ad_type, placement_id FROM test_data WHERE timestamp >= '2019-09-01' AND timestamp <= '2019-09-02' AND game LIKE '%mario%' ORDER BY ad_type"
+        self.assertEqual(returned_query, return_query)
+
     @classmethod
     def setUpClass(cls):
         super().setUp(cls)
